@@ -124,6 +124,7 @@
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
+#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
 #define HAVE_DECL_SYS_NERR 1
@@ -210,7 +211,6 @@
 #define HAVE_WORKING_FORK 1
 #define HAVE___SYSCALL 1
 #define HAVE__LONGJMP 1
-#define HAVE__SETJMP 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
@@ -300,10 +300,14 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP16 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP32 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP64 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
@@ -338,9 +342,9 @@
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
-#define RUBY_SETJMP(env) _setjmp((env))
-#define RUBY_LONGJMP(env,val) _longjmp((env),val)
-#define RUBY_JMP_BUF jmp_buf
+#define RUBY_SETJMP(env) sigsetjmp((env),0)
+#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
+#define RUBY_JMP_BUF sigjmp_buf
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "i386-openbsd"
 #endif /* INCLUDE_RUBY_CONFIG_H */
