@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.2.6"[/^[0-9]+[.][0-9]+[.]/]) or
-    raise "ruby lib version (2.2.6) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.2.8"[/^[0-9]+[.][0-9]+[.]/]) or
+    raise "ruby lib version (2.2.8) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.2/x86_64-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,8 +13,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "2"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "396"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.2.6/bin/install -c '
+  CONFIG["PATCHLEVEL"] = "477"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.2.8/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)22"
@@ -78,14 +78,14 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.2"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.3"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=iso9899:1999"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
@@ -145,9 +145,9 @@ module RbConfig
   CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.2.6/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.2.6/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.2.6/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.2.8/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.2.8/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.2.8/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -181,22 +181,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd6.1"
+  CONFIG["target_os"] = "openbsd6.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "x86_64"
-  CONFIG["target"] = "x86_64-unknown-openbsd6.1"
-  CONFIG["host_os"] = "openbsd6.1"
+  CONFIG["target"] = "x86_64-unknown-openbsd6.2"
+  CONFIG["host_os"] = "openbsd6.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "x86_64"
-  CONFIG["host"] = "x86_64-unknown-openbsd6.1"
+  CONFIG["host"] = "x86_64-unknown-openbsd6.2"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.1"
+  CONFIG["build_os"] = "openbsd6.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "x86_64"
-  CONFIG["build"] = "x86_64-unknown-openbsd6.1"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.6"
+  CONFIG["build"] = "x86_64-unknown-openbsd6.2"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.8"
   CONFIG["HAVE_BASERUBY"] = "no"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
